This patch contains all the Debian-specific changes mixed together.
The reason for doing this, rather than maintaining quilt patches, is
that the Debian-specific changes are maintained as a branch in a
fossil repository.  To review them separately, please inspect the
debian branch in http://people.debian.org/~bap/fossil.fsl
--- fossil-2.18.orig/extsrc/shell.c
+++ fossil-2.18/extsrc/shell.c
@@ -1403,7 +1403,7 @@ INT closedir(
 ** The sha3(X) function computes the SHA3 hash of the input X, or NULL if
 ** X is NULL.
 **
-** The sha3_query(Y) function evalutes all queries in the SQL statements of Y
+** The sha3_query(Y) function evaluates all queries in the SQL statements of Y
 ** and returns a hash of their results.
 **
 ** The SIZE argument is optional.  If omitted, the SHA3-256 hash algorithm
--- fossil-2.18.orig/extsrc/sqlite3.c
+++ fossil-2.18/extsrc/sqlite3.c
@@ -136796,7 +136796,7 @@ static int multiSelectOrderBy(
 ** The "LIMIT of exactly 1" case of condition (1) comes about when a VALUES
 ** clause occurs within scalar expression (ex: "SELECT (VALUES(1),(2),(3))").
 ** The sqlite3CodeSubselect will have added the LIMIT 1 clause in tht case.
-** Since the limit is exactly 1, we only need to evalutes the left-most VALUES.
+** Since the limit is exactly 1, we only need to evaluate the left-most VALUES.
 */
 static int multiSelectValues(
   Parse *pParse,        /* Parsing context */
--- fossil-2.18.orig/manifest
+++ fossil-2.18/manifest
@@ -1,5 +1,5 @@
-C Version\s2.18
-D 2022-02-23T13:22:20.620
+C update\sdebian/changelog
+D 2022-02-23T13:54:02.546
 F .dockerignore cd9c1b2de67ec60db244641291e2b5d8288e1d25fca4bf5a322592a98e3680d5
 F .editorconfig 132c5a213aa3ce13dcc9c19f8a7ea306e3640bec4ae693378116cee339c34a1a
 F .fossil-settings/binary-glob de2f79514803c25633f3d21103fd37a5b6cd428761c166dc0e92a302da66d919
@@ -31,7 +31,6 @@ F autosetup/cc-lib.tcl 8f02d3adf5051668b
 F autosetup/cc-shared.tcl 381d7305415d3c4509554cc762e094b6b4897fa05ba1fe6d103c02c71405c3d3
 F autosetup/cc.tcl 31f369a8859ccf285fd6535c6774ad8c62fe3988bb7043b3a07708d4a52127d0
 F autosetup/default.auto f78163e478676728918cbb7360abddb9c830e882
-F autosetup/jimsh0.c be75b9febfbccda4ea0df49f1cd55b66377f23b6cb944c3363f08ed796366bf6
 F autosetup/local.tcl 60b0633b484a89c87aed299e4c22ac5287803f921ba9b653a04b0c518f699cda
 F autosetup/pkg-config.tcl f53e22f94db8541ce3466103e242a3e8e716bc4f0c209eaa34beee0a9f949935
 F autosetup/system.tcl 4fe004b7d41213044360db4918729a5854336e460ff09cd5d555d506985b66a5
@@ -79,7 +78,6 @@ F compat/zlib/contrib/delphi/ZLibConst.p
 F compat/zlib/contrib/delphi/readme.txt 366e08eaa227cd3d09810c45639aedf4879b7ecf
 F compat/zlib/contrib/delphi/zlibd32.mak ddf83b34d4c7d41ace39f96b5cb13fb390c8d2eb
 F compat/zlib/contrib/dotzlib/DotZLib.build 6f87ba12d786feca35738d0e9ce1f0f03f292881
-F compat/zlib/contrib/dotzlib/DotZLib.chm a1245c21c7e918fa2919fd10bbe5604fc81faf49
 F compat/zlib/contrib/dotzlib/DotZLib.sln 4946bdb71b79bff62f9217802b7524010c669408
 F compat/zlib/contrib/dotzlib/DotZLib/AssemblyInfo.cs 9f1db1177b2e9a014f72bb3cd80be17133e06d16
 F compat/zlib/contrib/dotzlib/DotZLib/ChecksumImpl.cs 3807a0e24a57b92ea301559cab7307b8eab52c51
@@ -289,14 +287,27 @@ F compat/zlib/zlib2ansi e9859eecf47ae662
 F compat/zlib/zutil.c 2f1fcc93488ac84acf984415b6ea0bd63c72aa49
 F compat/zlib/zutil.h f32dab3880d47eca1b71c308cf6542b32941b23c
 F configure 05e4b3ca2e1ff283d82e0c4ced9215edc47157c4b4ba6839fb7f895bf224dcd2 x
-F debian/makedeb.sh a6f25e2697977d7865196cc87b67271575681d2fc148256b58bdd574bd49a5d7
+F debian/README.Debian e678b3c6de3ce5f7020ead24f62751317dd5ba2d7cca03511cfe8f53f1b0e648
+F debian/changelog ebabfcf0b680e5588e98a5175c8e86301245b2ca7b067d399571865e948fddc7
+F debian/clean 65cc2108142dc3df843e4f30c0fcebd3c7a5cfd3e3209eadd8a26a7e00c1e833
+F debian/control e527d6520bf96417c62832bcde9574a3ce465bf10fe7f0629dbdab221e649270
+F debian/copyright 39f1cc441231142d81e631e6d0764eb5193f4aef6b441aaa23298f82dce120fc
+F debian/fossil.bash-completion e1e460f40668463a8e3e8df9a99de8f9301c9730
+F debian/fossil.docs 45a770a8534b1a439a32546145737975a9217b30
+F debian/fossil.manpages 8ca3a843375393ec37484e4dbae3d4dfe5b4ddcf
+F debian/rules a514c718065b4547bf8784375a48331bfa4797cc9c7501c7d350593bde13756d x
+F debian/source/format 1064dc0ce263680c076a1005f35ec906a5cf5a32
+F debian/source/local-options 58a65fc3dfe4bbb8692c99e80334fba1e913f072
+F debian/source/patch-header 84c8aca673f2fc094c29a10bd519fca36a57e9f6
+F debian/tests/control 70e1a35bc70ffe690fcab7997da62bf0329852caf34756c54c71c5b12a5690a2
+F debian/watch 05a59eaa16f3b84bcf0cd105c0265d738f6020ab7ddb0562f41820d66f014a20
 F extsrc/cson_amalgamation.c 0bb78744f0ff615a6f47edf0c2519e2e078453b8c2ab9b19edcc37fe1a571618
 F extsrc/cson_amalgamation.h 199585e9e88fa59d6de79dab261112652075cad98c425f599ef55cad08b55569
 F extsrc/linenoise.c 6424bedb7816544d6eb61ec1895b114a727c2a05a1bca3d84cbaf1f199962b06
 F extsrc/linenoise.h fd137429d2d0255da02f0abceb772e9cc439c8c51c9a395a839e1c88a6a2bcf1
 F extsrc/pikchr.c dc374dad64dbe9738c6e899317ea333699c06db1d955b824f8b80605e19d209a
-F extsrc/shell.c 02fd19e622239f14ce71d3170850612af71106c43118a3e695702ab5d70047af
-F extsrc/sqlite3.c a69af0a88d59271a2dd3c846a3e93cbd29e7c499864f6c0462a3b4160bee1762
+F extsrc/shell.c c6c2587814d3a4933308a133eb1cfb04b7e25d3031e59f8300172bdcc7d89b52
+F extsrc/sqlite3.c 0ce8f3d377d812c04d66a7ea11fca6de6cb5aa6d3ab10174d4dad1607eefc0ca
 F extsrc/sqlite3.h a232c2a6cd0cec866cc133bf165626a8ce2f73d6a7c9219822dee953733e763a
 F fossil.1 bd002c154b826e6fbf622f39c6118f0170dc56fc558ff0ba3f7cc8e9896ed945
 F setup/fossil.iss b3a33fb693933cd55cb36761ef3f6634a3daab6b8697a9cd316e64de11dec7f3
@@ -396,7 +407,7 @@ F src/Makefile 102203d824d778194b79680be
 F src/accordion.js 4a4dd11a0e8e4e592846dc4b94cc873cc366e1a637811567e2eb249f16b8a64e
 F src/add.c feca4f3e28189e2ece07ee5260ff0ed7fb4c1125f39c3e30f5c7d916745eb62a
 F src/ajax.c 4d31ef8e51bdd3c3ac74f346d3604e27893ab5a879846312b576d76d15d38d41
-F src/alerts.c 33ad6b12748dc496bc98bf071be29769d4c66035e686d9b9f759fa6d9b74ad70
+F src/alerts.c 51dec530cea3502a9d4d99c7131e90539f65af43bf06b1a508107019c85d1957
 F src/alerts/bflat2.wav 79fa9b74167fbc7f70309879a36c9cb11e188644ea2ad9bdeaaef07a2dfb36c4
 F src/alerts/bflat3.wav 592aef32fdebdde8d960d1d41e78d23f57087b6b8449aa1008fa39e833137b6d
 F src/alerts/bloop.wav 765ed2eb421bb140bcb49061399d94fb4293d62213a9a81c54ecfd49be6c9643
@@ -414,7 +425,7 @@ F src/browse.c 8cf3a682649156a0b146c1f05
 F src/builtin.c e744959a71b209c879ad6c391d97220f63d5fc94cdd4942b2af598de9b50dc0b
 F src/bundle.c 10278fa9db8452a5428c9c54addc0f84d7c6025d2f237f0527adc747b09c2b49
 F src/cache.c 6b48b3e8d9caba50156db7119d736a5585387b0bd9353f312f14481d07cd2f6c
-F src/capabilities.c bd7c9b025602cdbe9a866dcf6ba14195551dac1ffe38c2eabdf86bb59780f73c
+F src/capabilities.c cc5e22191f5c42bd0b3897c4a00eee2f1f322387fc5300d90629ddd7e82dc455
 F src/captcha.c 508b596af187db92ab12cfe68ce31bce2ac62cd3633841c246e65a1e85e946ec
 F src/cgi.c b10651443f5c35ae2d8968fe93f90f82b0af88962d2cf2c7d8a8638f230933f8
 F src/chat.c 7fde154a7bc901fd53492921a3b3b118a6cf77e557b92440190ffd436bef246b
@@ -542,8 +553,8 @@ F src/rss.c 25bce3b3c670c02e032c6c5070f4
 F src/schema.c 07f674a17d00b8992be34d2a42e2dd45aef5790aa8f0fc2fcac5cd556dbc8d78
 F src/scroll.js 1f711eb8059a6baffcce9ed440d3e27c46201d38c929214965536f08453b6e23
 F src/search.c 835fca879dd9ef31b17b004c9cea96ae1ee559f77610c99f48558585befd18ad
-F src/security_audit.c 469601d1390cedb5fd973917b5468bcbfeb415a452401ed630a83ef23dd586f3
-F src/setup.c b4e93c821942ba7e56e94904791cbcc7743284cbb8ceba177bd7ffecb81bad29
+F src/security_audit.c 5d9017b53cec0f35f83c807c2588bd1f7d723a45cc1182615b10c7ea363ccd6e
+F src/setup.c 5882307205aa4e94ae3efbc5574c5ead87c43ee88bcc69f8e3c790c3789e3925
 F src/setupuser.c 7fe18356b3fe5f7855f2b87a62a7abe3b28716dc77e563dfb6073d9583449969
 F src/sha1.c a0b572370cf68fa813c55f983de9e4db527401f466d1d80e4e363e255c0e6d66
 F src/sha1hard.c e90831822166f79ff8a9830aaaca56923fe414a2
@@ -956,7 +967,7 @@ F www/sync.wiki 194982be00ac12c7d07eb184
 F www/tech_overview.wiki da5c3d1634fd953f7eacf0554cd5cb2895b654b478d8c428eac8bc780992524a
 F www/th1-hooks.md 01090d9200962b10c5068bd32a9de39f5972db651270040441f4ff7fd030641b
 F www/th1.md 23e7b8566a7ad19e4f174811d75d582fdc4c319dd150dd804deae96909a9d756
-F www/theory1.wiki c5a3a5c9c81a94787d20eacd5184f8afa0c7519efaacd75f84633d129763644a
+F www/theory1.wiki b12d58c80fb3a9860a8dd17452af6f4857bbdf13
 F www/tickets.wiki 6bbf8b9f0cf6e06e19b466af1880b56a56021bfc67ad2c5d6936503aaa5f5d5d
 F www/tls-nginx.md c94d41eb349702e444704a3f74cd3f38caf820ff3546ac71b749bbf80890698f
 F www/uitest.html a97f05c122479801f403711edb0ba588446e1baa509c9b81e22fa3d9404294c6
@@ -969,9 +980,7 @@ F www/whyusefossil.wiki b91ab7f82ace6a54
 F www/wikitheory.wiki 09c04354dbcc1c8c9d273354074d1653dd768fa5b7fe7b147c45cf36cc275fc4
 F www/wsl_caveats.wiki dc4a8388b29d05641ad4d9769c18cbe49963d000dbdc3a9dd6f616ccbcf12dea
 F www/xkcd-git.gif 1f9bc44ed41cad3f5ac18f21e3463e3390b53b29
-P 0a91005e3514633abf39374ecd57fa6f6fc40b2ed429461406f9d9928b8bed07
-R 7d1048e6dc54b51d97bd6d6133ffc3ba
-T +sym-release *
-T +sym-version-2.18 *
-U drh
-Z 7effe6d0f492e935d67d98c31f0b1144
+P c8b1d33325df63d086e6fe88bb2cc5d0976caef30c19c3bbed4b12b169f75665
+R 45f11a0e480169a2ebaeb9cc1b3b7e78
+U barak
+Z 6d63ee980378f6d42533cc9d6094dca6
--- fossil-2.18.orig/manifest.uuid
+++ fossil-2.18/manifest.uuid
@@ -1 +1 @@
-84f25d7eb10c0714109d69bb2809abfa8b4b5c3d73b151a5b10df724dacd46d8
+c47fa2469e22cfa86ab4025748202d1eb88984fa5b8a36610199ee80d16b5deb
--- fossil-2.18.orig/src/capabilities.c
+++ fossil-2.18/src/capabilities.c
@@ -277,7 +277,7 @@ static struct Caps {
   { 'r', CAPCLASS_TKT, 0,
     "Read-Tkt", "View tickets" },
   { 's', CAPCLASS_SUPER, 0,
-    "Superuser", "Setup and configure the respository" },
+    "Superuser", "Setup and configure the repository" },
   { 't', CAPCLASS_TKT, 0,
     "Reports", "Create new ticket report formats" },
   { 'u', CAPCLASS_OTHER, 0,
--- fossil-2.18.orig/src/security_audit.c
+++ fossil-2.18/src/security_audit.c
@@ -527,7 +527,7 @@ void secaudit0_page(void){
   if( db_get_boolean("access-log",0)==0 ){
     @ <li><p>
     @ The <a href="access_log">User Log</a> is disabled.  The user log
-    @ keeps a record of successful and unsucessful login attempts and is
+    @ keeps a record of successful and unsuccessful login attempts and is
     @ useful for security monitoring.
   }
   if( db_get_boolean("admin-log",0)==0 ){
--- fossil-2.18.orig/src/alerts.c
+++ fossil-2.18/src/alerts.c
@@ -316,7 +316,7 @@ void setup_notification(void){
   @ <p>When the send method is "pipe to a command", this is the command
   @ that is run.  Email messages are piped into the standard input of this
   @ command.  The command is expected to extract the sender address,
-  @ recepient addresses, and subject from the header of the piped email
+  @ recipient addresses, and subject from the header of the piped email
   @ text.  (Property: "email-send-command")</p>
 
   entry_attribute("Store Emails In This Database", 60, "email-send-db",
@@ -818,7 +818,7 @@ void email_header_to_free(int nTo, char
 /*
 ** Send a single email message.
 **
 ** The recepient(s) must be specified using  "To:" or "Cc:" or "Bcc:" fields
 ** in the header.  Likewise, the header must contains a "Subject:" line.
 ** The header might also include fields like "Message-Id:" or
 ** "In-Reply-To:".
@@ -818,7 +818,7 @@ void email_header_to_free(int nTo, char
 ** Send a single email message.
 **
-** The recepient(s) must be specified using  "To:" or "Cc:" or "Bcc:" fields
+** The recipient(s) must be specified using  "To:" or "Cc:" or "Bcc:" fields
 ** in the header.  Likewise, the header must contains a "Subject:" line.
 ** The header might also include fields like "Message-Id:" or
--- fossil-2.18.orig/src/setup.c
+++ fossil-2.18/src/setup.c
@@ -1033,7 +1033,7 @@ void setup_settings(void){
 **       repository root.
 **
 **   *   The third term is an argument to the TH1 "capexpr" command.
 **       If capexpr evalutes to true, then the entry is shown.  If not,
 **       the entry is omitted.  "*" is always true.  "{}" is never true.
 **
 **   *   The fourth term is a list of extra class names to apply to the
@@ -1064,7 +1064,7 @@ void setup_settings(void){
 **       repository root.
 **
 **   *   The third term is an argument to the TH1 "capexpr" command.
 **       If capexpr evalutes to true, then the entry is shown.  If not,
 **       the entry is omitted.  "*" is always true.
 **
 ** The default value is blank, meaning no added entries.
@@ -1164,7 +1164,7 @@ void setup_config(void){
   @      entry.  Hyperlinks that start with "/" are relative to the
   @      repository root.
   @ <li> The third term is an argument to the TH1 "capexpr" command.
-  @      If capexpr evalutes to true, then the entry is shown.  If not,
+  @      If capexpr evaluates to true, then the entry is shown.  If not,
   @      the entry is omitted.  "*" is always true.  "{}" is never true.
   @ <li> The fourth term is a list of extra class names to apply to the new
   @      menu entry.  Some skins use classes "desktoponly" and "wideonly"
@@ -1202,7 +1202,7 @@ void setup_config(void){
   @      entry.  Hyperlinks that start with "/" are relative to the
   @      repository root.
   @ <li> The third term is an argument to the TH1 "capexpr" command.
-  @      If capexpr evalutes to true, then the entry is shown.  If not,
+  @      If capexpr evaluates to true, then the entry is shown.  If not,
   @      the entry is omitted.  "*" is always true.
   @ </ol>
   @
@@ -1033,7 +1033,7 @@ void setup_settings(void){
 **
 **   *   The third term is an argument to the TH1 "capexpr" command.
-**       If capexpr evalutes to true, then the entry is shown.  If not,
+**       If capexpr evaluates to true, then the entry is shown.  If not,
 **       the entry is omitted.  "*" is always true.  "{}" is never true.
 **
@@ -1064,7 +1064,7 @@ void setup_settings(void){
 **
 **   *   The third term is an argument to the TH1 "capexpr" command.
-**       If capexpr evalutes to true, then the entry is shown.  If not,
+**       If capexpr evaluates to true, then the entry is shown.  If not,
 **       the entry is omitted.  "*" is always true.
 **
